@@ -160,10 +160,16 @@ void WnnKeyEventList::append(int code,int mask) {
 }
 
 bool WnnKeyEventList::comp(const KeyEvent &k) {
+    int kc = k.get_ascii_code();
+    if ((kc > 0x60) && (kc < 0x7b)) kc -= 0x20;
+    else if ((kc > 0x40) && (kc < 0x5b)) kc += 0x20;
     for (unsigned int i = 0;i < size();i ++) {
         if ((at(i).code == k.code) && (at(i).mask == k.mask)) {
             return(true);
         }
+        if (kc && (at(i).code == kc) && (at(i).mask == k.mask)) {
+            return(true);
+        }
     }
     return(false);
 }
@@ -209,13 +215,17 @@ void WnnInstance::init()
     numkeyselect = _scim_config->read(String(SCIM_CONFIG_WNN_NUMKEY_SELECT),SCIM_DEFAULT_WNN_NUMKEY_SELECT);
     yosoku = _scim_config->read(String(SCIM_CONFIG_WNN_YOSOKU),SCIM_DEFAULT_WNN_YOSOKU);
     String t = _scim_config->read(String(SCIM_CONFIG_WNN_SERVERTYPE),String(SCIM_DEFAULT_WNN_SERVERTYPE));
+
     if (t == "Wnn6") {
         sType = Wnn6;
     } else if (t == "Wnn7") {
         sType = Wnn7;
+    } else if (t == "Wnn8") {
+        sType = Wnn8;
     } else {
         sType = Wnn4;
     }
+
     defaultPreEditor = _scim_config->read(String(SCIM_CONFIG_WNN_DEFAULT_PREEDITOR),String(SCIM_DEFAULT_WNN_DEFAULT_PREEDITOR));
     auto_conversion = _scim_config->read(String(SCIM_CONFIG_WNN_AUTO_CONVERSION),SCIM_DEFAULT_WNN_AUTO_CONVERSION);;
 
@@ -280,6 +290,12 @@ void WnnInstance::init()
     scim_string_to_key_list(k_convert_katakana,
         _scim_config->read(String(SCIM_CONFIG_WNN_KEY_CONVERT_KATAKANA),
             String(SCIM_DEFAULT_WNN_KEY_CONVERT_KATAKANA)));
+    scim_string_to_key_list(k_convert_half,
+        _scim_config->read(String(SCIM_CONFIG_WNN_KEY_CONVERT_HALF),
+            String(SCIM_DEFAULT_WNN_KEY_CONVERT_HALF)));
+    scim_string_to_key_list(k_convert_wide,
+        _scim_config->read(String(SCIM_CONFIG_WNN_KEY_CONVERT_WIDE),
+            String(SCIM_DEFAULT_WNN_KEY_CONVERT_WIDE)));
 
     scim_string_to_key_list(k_conversion_rensou,
         _scim_config->read(String(SCIM_CONFIG_WNN_KEY_CONVERSION_RENSOU),
@@ -420,9 +436,13 @@ void WnnInstance::updateConversion()
 bool WnnInstance::process_key_event (const KeyEvent& key)
 {
     if (key.is_key_release()) return(false);
-    if (m_conversion) return(process_conversion_key_event(key));
-    else if (m_yosoku) return(process_yosoku_key_event(key));
-    else return(process_preedit_key_event(key));
+    KeyEvent ke = key;
+    if (ke.mask & SCIM_KEY_CapsLockMask) ke.mask -= SCIM_KEY_CapsLockMask;
+    if (ke.mask & SCIM_KEY_NumLockMask) ke.mask -= SCIM_KEY_NumLockMask;
+    if (ke.mask & SCIM_KEY_ScrollLockMask) ke.mask -= SCIM_KEY_ScrollLockMask;
+    if (m_conversion) return(process_conversion_key_event(ke));
+    else if (m_yosoku) return(process_yosoku_key_event(ke));
+    else return(process_preedit_key_event(ke));
 }
 
 
@@ -478,6 +498,16 @@ bool WnnInstance::process_preedit_key_event(const KeyEvent &key)
             updatePreEditor();
             return(true);
         } else
+        if (k_convert_half.comp(key)) {
+            m_preeditor->toHalf();
+            updatePreEditor();
+            return(true);
+        } else
+        if (k_convert_wide.comp(key)) {
+            m_preeditor->toWide();
+            updatePreEditor();
+            return(true);
+        } else
         if (k_select_yosoku.comp(key) && yosoku) {
             if ((m_convList.kType == YOSOKU) && (m_convList.count)) {
                 return(process_yosoku_key_event(key));
@@ -599,7 +629,7 @@ bool WnnInstance::process_conversion_key_event(const KeyEvent &key)
         alp_count = 1;
         return(true);
     } else
-    if (k_conversion_rensou.comp(key) && (sType == Wnn7) ) {
+    if (k_conversion_rensou.comp(key) && ((sType == Wnn7) || (sType == Wnn8)) ) {
         m_convList = wnn.getConversionList(wnn.getPos(),RENSOU);
         if (m_convList.count == 0) return(true);
         startLookup();
@@ -607,7 +637,7 @@ bool WnnInstance::process_conversion_key_event(const KeyEvent &key)
         alp_count = 1;
         return(true);
     } else
-    if (k_conversion_ikeiji.comp(key) && (sType == Wnn7)) {
+    if (k_conversion_ikeiji.comp(key) && ((sType == Wnn7) || (sType == Wnn8)) ) {
         m_convList = wnn.getConversionList(wnn.getPos(),IKEIJI);
         if (m_convList.count == 0) return(true);
         startLookup();
