@@ -153,6 +153,7 @@ static bool __config_yosoku = SCIM_DEFAULT_WNN_YOSOKU;
 static bool __config_numkeyselect = SCIM_DEFAULT_WNN_NUMKEY_SELECT;
 static bool __config_autoconversion = SCIM_DEFAULT_WNN_AUTO_CONVERSION;
 static int __config_alp = SCIM_DEFAULT_WNN_ALP;
+static String __config_romkan_table = SCIM_DEFAULT_WNN_ROMKAN_TABLE_FILE;
 
 static bool __have_changed    = true;
 
@@ -165,6 +166,7 @@ static GtkWidget    * __widget_yosoku = 0;
 static GtkWidget    * __widget_alp = 0;
 static GtkWidget    * __widget_numkeyselect = 0;
 static GtkWidget    * __widget_autoconversion = 0;
+static GtkWidget    * __widget_romkan_table = 0;
 static GtkTooltips  * __widget_tooltips = 0;
 
 static ListData __list_data [] =
@@ -184,6 +186,11 @@ static ListData __list_data [] =
         String("Wnn7"),
         N_("Wnn7"),
     },
+    {
+        NULL,
+        String("Wnn8"),
+        N_("Wnn8"),
+    },
     {
         NULL,
         String("Romkan"),
@@ -492,7 +499,7 @@ static void setup_widget_value (void);
 static GtkWidget *
 create_options_page ()
 {
-    GtkWidget *vbox, *table, *label, *button;
+    GtkWidget *vbox, *table, *label, *button, *button2;
     unsigned int i;
     GList *list = NULL;
 
@@ -576,6 +583,7 @@ create_options_page ()
     list = g_list_append(list,__list_data[0].widget);
     list = g_list_append(list,__list_data[1].widget);
     list = g_list_append(list,__list_data[2].widget);
+    list = g_list_append(list,__list_data[3].widget);
     __widget_servertype = gtk_list_new ();
     gtk_list_append_items(GTK_LIST(__widget_servertype),list);
     gtk_widget_show (__widget_servertype);
@@ -596,8 +604,8 @@ create_options_page ()
                       (GtkAttachOptions) (GTK_FILL), 4, 4);
 
     list = NULL;
-    list = g_list_append(list,__list_data[3].widget);
     list = g_list_append(list,__list_data[4].widget);
+    list = g_list_append(list,__list_data[5].widget);
     __widget_preeditor = gtk_list_new ();
     gtk_list_append_items(GTK_LIST(__widget_preeditor),list);
     gtk_widget_show (__widget_preeditor);
@@ -685,6 +693,32 @@ create_options_page ()
                               _("if you use YOSOKU-input , check this."), NULL);
 
 
+    // romkan_table
+    label = gtk_label_new_with_mnemonic (_("_Roma-Kana table: "));
+    gtk_widget_show (label);
+    gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+    gtk_misc_set_padding (GTK_MISC (label), 4, 0);
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 8, 9,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (GTK_FILL), 4, 4);
+
+    __widget_romkan_table = gtk_entry_new ();
+    gtk_widget_show (__widget_romkan_table);
+    gtk_table_attach (GTK_TABLE (table), __widget_romkan_table, 1, 2, 8, 9,
+                      (GtkAttachOptions) (GTK_FILL|GTK_EXPAND),
+                      (GtkAttachOptions) (GTK_FILL), 4, 4);
+    gtk_label_set_mnemonic_widget (GTK_LABEL (label), __widget_romkan_table);
+
+    button2 = gtk_button_new_with_label (_("..."));
+    gtk_widget_show (button2);
+    gtk_table_attach (GTK_TABLE (table), button2, 2, 3, 8, 9,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (GTK_FILL), 4, 4);
+    gtk_tooltips_set_tip (__widget_tooltips, __widget_romkan_table,
+                              _("input the path of Roma-Kana convert table file."), NULL);
+
+
+
     /* connect all signals */
     g_signal_connect ((gpointer) __widget_server, "changed",
                       G_CALLBACK (on_default_editable_changed),
@@ -713,6 +747,12 @@ create_options_page ()
     g_signal_connect ((gpointer) __widget_yosoku, "toggled",
                       G_CALLBACK (on_default_toggle_button_toggled),
                       &__config_yosoku);
+    g_signal_connect ((gpointer) __widget_romkan_table, "changed",
+                      G_CALLBACK (on_default_editable_changed),
+                      &__config_romkan_table);
+    g_signal_connect ((gpointer) button2, "clicked",
+                      G_CALLBACK (on_default_file_selection_button),
+                      __widget_romkan_table);
 
     return vbox;
 }
@@ -871,6 +911,12 @@ setup_widget_value (void)
             __config_yosoku);
     }
 
+    if (__widget_romkan_table) {
+        gtk_entry_set_text (
+            GTK_ENTRY (__widget_romkan_table),
+            __config_romkan_table.c_str ());
+    }
+
     for (unsigned int j = 0; j < __key_conf_pages_num; ++ j) {
         for (unsigned int i = 0; __key_conf_pages[j].data[i].key; ++ i) {
             if (__key_conf_pages[j].data[i].entry) {
@@ -913,6 +959,9 @@ load_config (const ConfigPointer &config)
         __config_yosoku =
             config->read (String (SCIM_CONFIG_WNN_YOSOKU),
                           __config_yosoku);
+        __config_romkan_table =
+            config->read (String (SCIM_CONFIG_WNN_ROMKAN_TABLE_FILE),
+                          __config_romkan_table);
 
         for (unsigned int j = 0; j < __key_conf_pages_num; j++) {
             for (unsigned int i = 0; __key_conf_pages[j].data[i].key; ++ i) {
@@ -950,6 +999,8 @@ save_config (const ConfigPointer &config)
                        __config_autoconversion);
         config->write (String (SCIM_CONFIG_WNN_YOSOKU),
                        __config_yosoku);
+        config->write (String (SCIM_CONFIG_WNN_ROMKAN_TABLE_FILE),
+                       __config_romkan_table);
 
         for (unsigned j = 0; j < __key_conf_pages_num; j++) {
             for (unsigned int i = 0; __key_conf_pages[j].data[i].key; ++ i) {
